@@ -6,6 +6,7 @@ from .MultiSampleScore import *
 from .callDirectionalTAD import *
 from .calldTADAllchr import *
 from .discrete import *
+from .stripe import *
 
 def CLI():
     parser = argparse.ArgumentParser(description="HiC1Dmetrics is python3-based tools to \
@@ -53,7 +54,7 @@ def CLI():
             makeIntra = codepath+"/extract/makeMatrixIntra.sh"
             juicer = codepath+"/jc/jctool_1.11.04.jar"
             foldername = args.outname
-            os.system("sh "+makeIntra+" "+args.normalize+" "+"."+" "+args.matrix+" "+
+            os.system("bash "+makeIntra+" "+args.normalize+" "+"."+" "+args.matrix+" "+
                     str(args.resolution)+" "+args.gt+" "+juicer+" "+args.chromosome+" "+foldername)
         elif args.mode == "gd":
             codepath = os.path.dirname(os.path.realpath(__file__))
@@ -96,7 +97,7 @@ def CLI():
             args.parameter = int(args.parameter)
 
         score = multiScore(args.matrix,args.resolution,args.chromosome,
-                            ).obtainOneScore(args.type,parameter=args.parameter,datatype=args.datatype,gt=args.gt,TADfile=args.TADfile)
+                            ).obtainOneScore(args.type,parameter=args.parameter,datatype=args.datatype,gt=args.gt,TADfile=args.TADfile,msi=args.msi)
         score.to_csv(args.outname + ".bedGraph", sep="\t", header=False, index=False)
 
         if args.draw:
@@ -121,7 +122,8 @@ def CLI():
     parser_one.add_argument("-d","--draw",action='store_true',help="Plot figure for candidate region.",default=False)
     parser_one.add_argument("-s",'--start',type=int,help="Start sites for plotting.",default=0)
     parser_one.add_argument("-e",'--end',type=int,help="End sites for plotting.",default=0)
-    parser_one.add_argument('--datatype',type=str,help="Type of input data: matrix(default) or rawhic.",default="matrix")
+    parser_one.add_argument('--datatype',type=str,help="Type of input data: [matrix(default),rawhic,cool].",default="matrix")
+    parser_one.add_argument('--msi',type=str,help="Method for significant interactions: [fithic2,hiccups]",default="fithic2")
     parser_one.add_argument('--gt',type=str,help="genome_table file.",default="")
     parser_one.add_argument('--prefix',type=str,help="${prefix}chr1.matrix.gz",default="observed.KR.")
     parser_one.add_argument('--maxchr',type=int,help="Maximum index of chromosome (human genome is 22,i.e.)",default=None)
@@ -337,10 +339,14 @@ def CLI():
             leftdTAD,rightdTAD,_ = dt.extractRegion()
             leftdTAD.to_csv(args.outname + "_leftdTAD.csv", sep="\t", header=True, index=False)
             rightdTAD.to_csv(args.outname + "_rightdTAD.csv", sep="\t", header=True, index=False)
-        elif args.mode == "stripe":
+        elif args.mode == "stripeTAD":
             st = stripeTAD(path,args.resolution,args.chromosome)
-            stripe = st.callStripe(squareSize=300000)
-            stripe.to_csv(args.outname + "_stripe.csv", sep="\t", header=True, index=False)
+            stripeTAD = st.callStripe(squareSize=300000)
+            stripeTAD.to_csv(args.outname + "_stripeTAD.csv", sep="\t", header=True, index=False)
+        elif args.mode == "stripe":
+            st = call_stripe(path,args.resolution,args.chromosome)
+            stripe = st.callStripe(squareSize=300000,strong_thresh=0.2)
+            stripe.to_csv(args.outname + "_stripes.csv", sep="\t", header=True, index=False)
         elif args.mode == "hubs":
             if args.datatype != "rawhic": print("Error: hubs requires rawhic datatype"); exit(1)
             IF = InteractionFrequency(path,args.resolution,args.chromosome,gt=args.gt).getIF()
@@ -353,7 +359,7 @@ def CLI():
 
     parser_call = subparsers.add_parser("call",help="Extract secondary information from metrics (dTAD, stripeTAD, et.al)",
                                             description="Extract secondary information from metrics (dTAD, stripeTAD, et.al)")
-    parser_call.add_argument('mode', type=str, help='Running mode,,should be one of {dTAD,stripe,TAD,hubs}')
+    parser_call.add_argument('mode', type=str, help='Running mode,,should be one of {dTAD,stripe,stripeTAD,TAD,hubs}')
     parser_call.add_argument('data', type=str, help='Path of matrix file or raw .hic file')
     parser_call.add_argument('resolution', type=int,help="Resolution of input matrix")
     parser_call.add_argument("chromosome",type=str,help="Chromosome number.")
@@ -367,7 +373,7 @@ def CLI():
     parser.add_argument("-V","--version",help="Show h1d version",action='store_true',default=False)
     args = parser.parse_args()
     if args.version:
-        print("h1d version 0.1.11")
+        print("h1d version 0.1.13")
         exit(0)
     try:
         func = args.func
